@@ -29,6 +29,7 @@ from pyplumio.exceptions import (
 from pyplumio.frames import Frame, Request, get_frame_handler, requests
 from pyplumio.helpers.data_types import Boolean
 from pyplumio.helpers.factory import factory
+from pyplumio.helpers.filters import on_change
 from pyplumio.helpers.parameter import (
     BoilerBinaryParameter,
     BoilerParameter,
@@ -37,6 +38,7 @@ from pyplumio.helpers.parameter import (
     Parameter,
     is_binary_parameter,
 )
+from pyplumio.helpers.task_manager import TaskManager
 from pyplumio.helpers.timeout import timeout
 from pyplumio.helpers.typing import (
     Numeric,
@@ -53,7 +55,7 @@ devices: Mapping[int, str] = {
 }
 
 
-VALUE_TIMEOUT: int = 5
+VALUE_TIMEOUT: int = 10
 
 
 def get_device_handler(address: int) -> str:
@@ -70,18 +72,15 @@ class FrameVersions:
     versions: MutableMapping[int, int]
     _queue: asyncio.Queue
     _device: Device
-    _required_frames: MutableMapping[int, int]
 
     def __init__(self, queue: asyncio.Queue, device: Device):
         """Initialize Frame Versions object."""
         self.versions = {}
         self._queue = queue
         self._device = device
-        self._required_frames = {x.frame_type: 0 for x in device.required_frames}
 
-    async def update(self, frame_versions: MutableMapping[int, int]) -> None:
-        """Check frame versions and fetch outdated frames."""
-        frame_versions = {**frame_versions, **self._required_frames}
+    def update(self, frame_versions: MutableMapping[int, int]) -> None:
+        """Check versions and fetch outdated frames."""
         for frame_type, version in frame_versions.items():
             if frame_type not in self.versions or self.versions[frame_type] != version:
                 # We don't have this frame or it's version has changed.
@@ -95,22 +94,20 @@ class FrameVersions:
                     # Ignore unknown frames in version list.
                     continue
 
-
-def _significantly_changed(old_value, new_value) -> bool:
-    """Check if value is significantly changed."""
-    if isinstance(old_value, float) and isinstance(new_value, float):
-        return round(old_value, 1) != round(new_value, 1)
-
-    return old_value != new_value
+    async def async_update(self, *args, **kwargs) -> None:
+        """Asynchronously check versions and fetch outdated frames."""
+        self.update(*args, *kwargs)
 
 
-class AsyncDevice(ABC):
+class AsyncDevice(ABC, TaskManager):
     """Represents a device with awaitable properties."""
 
     _callbacks: MutableMapping[str, MutableSequence[ValueCallback]]
 
     def __init__(self):
+        """Initializes Async Device object."""
         self._callbacks = {}
+        super().__init__()
 
     @timeout(VALUE_TIMEOUT)
     async def get_value(self, name: str):
@@ -149,19 +146,23 @@ class AsyncDevice(ABC):
 
         raise ParameterNotFoundError(f"parameter {name} not found")
 
-    async def async_set_attribute(
-        self, name: str, value, skip_change_check: bool = False
-    ) -> None:
+    def set_attribute(self, *args, **kwargs) -> None:
         """Call registered callbacks on value change."""
-        old_value = self.__dict__[name] if name in self.__dict__ else None
-        if name in self._callbacks and (
-            skip_change_check or _significantly_changed(old_value, value)
-        ):
+        self.create_task(self.async_set_attribute(*args, **kwargs))
+
+    async def async_set_attribute(self, name: str, value) -> None:
+        """Asynchronously call registered callbacks on value change."""
+        if name in self._callbacks:
             for callback in self._callbacks[name]:
                 return_value = await callback(value)
                 value = return_value if return_value is not None else value
 
-        self.__dict__[name] = value
+        setattr(self, name, value)
+
+    async def shutdown(self) -> None:
+        """Cancel scheduled tasks."""
+        self.cancel_tasks()
+        await self.wait_for_tasks()
 
     def register_callback(self, sensors: Sequence[str], callback: ValueCallback):
         """Register callback for sensor change."""
@@ -199,13 +200,14 @@ class Device(AsyncDevice):
         super().__init__()
         self._queue = queue
         versions = FrameVersions(queue, device=self)
-        self.register_callback([DATA_FRAME_VERSIONS], versions.update)
+        versions.update({x.frame_type: 0 for x in self.required_frames})
+        self.register_callback([DATA_FRAME_VERSIONS], on_change(versions.async_update))
 
-    async def handle_frame(self, frame: Frame) -> None:
+    def handle_frame(self, frame: Frame) -> None:
         """Handle received frame."""
         if frame.data is not None:
             for name, value in frame.data.items():
-                await self.async_set_attribute(name, value)
+                self.set_attribute(name, value)
 
     @property
     def required_frames(self) -> Sequence[Type[Request]]:
@@ -226,10 +228,10 @@ class EcoMAX(Device):
     _fuel_burned_timestamp: float = 0.0
     _required_frames: Sequence[Type[Request]] = [
         requests.UID,
-        requests.Password,
         requests.DataSchema,
         requests.BoilerParameters,
         requests.MixerParameters,
+        requests.Password,
     ]
 
     def __init__(self, queue: asyncio.Queue):
@@ -238,7 +240,9 @@ class EcoMAX(Device):
         self._mixers: MutableMapping[int, Mixer] = {}
         self._fuel_burned_timestamp = time.time()
         self.register_callback([DATA_BOILER_SENSORS], self._add_boiler_sensors)
-        self.register_callback([DATA_MODE], self._add_boiler_control_parameter)
+        self.register_callback(
+            [DATA_MODE], on_change(self._add_boiler_control_parameter)
+        )
         self.register_callback([DATA_FUEL_CONSUMPTION], self._add_burned_fuel_counter)
         self.register_callback([DATA_BOILER_PARAMETERS], self._add_boiler_parameters)
         self.register_callback([DATA_REGDATA], self._parse_regulator_data)
@@ -332,9 +336,7 @@ class EcoMAX(Device):
         seconds_passed = current_timestamp - self._fuel_burned_timestamp
         fuel_burned = (fuel_consumption / 3600) * seconds_passed
         self._fuel_burned_timestamp = current_timestamp
-        await self.async_set_attribute(
-            "fuel_burned", fuel_burned, skip_change_check=True
-        )
+        await self.async_set_attribute("fuel_burned", fuel_burned)
 
     async def _parse_regulator_data(self, regulator_data: bytes) -> Records:
         """Add sensor values from the regulator data."""
@@ -361,6 +363,13 @@ class EcoMAX(Device):
 
         return data
 
+    async def shutdown(self) -> None:
+        """Cancel scheduled tasks."""
+        for _, mixer in self.mixers.items():
+            await mixer.shutdown()
+
+        await super().shutdown()
+
 
 class EcoSTER(Device):
     """Represents ecoSTER thermostat."""
