@@ -1,10 +1,13 @@
 """Contains modules structure parser."""
+from __future__ import annotations
 
+from collections.abc import Sequence
 import struct
-from typing import Any, Dict, Final, Optional, Tuple
+from typing import Final, Optional, Tuple
 
-from pyplumio.constants import DATA_MODULES
+from pyplumio.const import DATA_MODULES
 from pyplumio.helpers.product_info import ConnectedModules
+from pyplumio.helpers.typing import Records
 
 MODULE_A: Final = "module_a"
 MODULE_B: Final = "module_b"
@@ -12,7 +15,7 @@ MODULE_C: Final = "module_c"
 MODULE_LAMBDA: Final = "module_lambda"
 MODULE_ECOSTER: Final = "module_ecoster"
 MODULE_PANEL: Final = "module_panel"
-MODULES: Final = (
+MODULES: Sequence[str] = (
     MODULE_A,
     MODULE_B,
     MODULE_C,
@@ -23,20 +26,15 @@ MODULES: Final = (
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Optional[Dict[str, Any]] = None
-) -> Tuple[Dict[str, Any], int]:
-    """Parses frame message into usable data.
-
-    Keyword arguments:
-        message -- message bytes
-        offset -- current data offset
-    """
+    message: bytearray, offset: int = 0, data: Optional[Records] = None
+) -> Tuple[Records, int]:
+    """Parse bytes and return message data and offset."""
     if data is None:
         data = {}
 
     connected_modules = ConnectedModules()
     for module_name in MODULES:
-        module_version, offset = _parse_module_version(module_name, message, offset)
+        module_version, offset = _get_module_version(module_name, message, offset)
         setattr(connected_modules, module_name, module_version)
 
     data[DATA_MODULES] = connected_modules
@@ -44,16 +42,10 @@ def from_bytes(
     return data, offset
 
 
-def _parse_module_version(
+def _get_module_version(
     module_name: str, message: bytearray, offset: int = 0
 ) -> Tuple[Optional[str], int]:
-    """Gets module version by module name.
-
-    Keyword arguments:
-        module_name - module name
-        message - bytes to parse module version from
-        offset - message offset
-    """
+    """Get module version from a message."""
     if message[offset] == 0xFF:
         return None, (offset + 1)
 
